@@ -95,13 +95,13 @@ void QzToolsTest::splitCommandArguments_data()
                            << QStringList();
     QTest::newRow("OnlySpaces") << QString("                   ")
                            << QStringList();
-    QTest::newRow("OnlyQuotes") << QString("\"\" \"\"")
+    QTest::newRow("OnlyQuotes") << QString(R"("" "")")
                            << QStringList();
-    QTest::newRow("EmptyQuotesAndSpace") << QString("\"\" \"\" \" \"")
+    QTest::newRow("EmptyQuotesAndSpace") << QString(R"("" "" " ")")
                            << QStringList(" ");
     QTest::newRow("MultipleSpaces") << "    /usr/foo   -o    foo.out    "
                            << (QStringList() << "/usr/foo" << "-o" << "foo.out");
-    QTest::newRow("Quotes") << "\"/usr/foo\" \"-o\" \"foo.out\""
+    QTest::newRow("Quotes") << R"("/usr/foo" "-o" "foo.out")"
                            << (QStringList() << "/usr/foo" << "-o" << "foo.out");
     QTest::newRow("SingleQuotes") << "'/usr/foo' '-o' 'foo.out'"
                            << (QStringList() << "/usr/foo" << "-o" << "foo.out");
@@ -111,7 +111,7 @@ void QzToolsTest::splitCommandArguments_data()
                            << (QStringList() << "/usr/foo" << "-o 'ds' " << "foo.out");
     QTest::newRow("DoubleInSingleQuotes") << "/usr/foo -o 'foo\" d \".out' "
                            << (QStringList() << "/usr/foo" << "-o" << "foo\" d \".out");
-    QTest::newRow("SpacesWithQuotes") << QString("  \"   \"     \"   \"     ")
+    QTest::newRow("SpacesWithQuotes") << QString(R"(  "   "     "   "     )")
                            << (QStringList() << "   " << "   ");
     QTest::newRow("QuotesAndSpaces") << "/usr/foo -o \"foo - out\""
                            << (QStringList() << "/usr/foo" << "-o" << "foo - out");
@@ -298,7 +298,7 @@ void QzToolsTest::copyRecursivelyTest()
 
     QVERIFY(!QFileInfo(testDir + "-copy").exists());
 
-    // Copy to non-existant target
+    // Copy to non-existent target
     QCOMPARE(QzTools::copyRecursively(testDir, testDir + "-copy"), true);
 
     QCOMPARE(QFileInfo(testDir + "-copy").isDir(), true);
@@ -333,7 +333,7 @@ void QzToolsTest::removeRecursivelyTest()
     QCOMPARE(QzTools::removeRecursively(testDir + "-copy"), true);
     QCOMPARE(QFileInfo(testDir + "-copy").exists(), false);
 
-    // Remove non-existant path returns success
+    // Remove non-existent path returns success
     QCOMPARE(QzTools::removeRecursively(testDir + "-copy"), true);
 
     QCOMPARE(QzTools::copyRecursively(testDir, testDir + "-copy2"), true);
