@@ -29,6 +29,7 @@
 #include <QStyleOptionButton>
 #include <QDrag>
 #include <QMimeData>
+#include <QtGuiVersion>
 
 #define MAX_WIDTH 150
 #define SEPARATOR_WIDTH 8
@@ -92,7 +93,7 @@ QSize BookmarksToolbarButton::sizeHint() const
         width = SEPARATOR_WIDTH;
     }
     else if (!m_showOnlyIcon) {
-        width += PADDING * 2 + fontMetrics().width(m_bookmark->title());
+        width += PADDING * 2 + fontMetrics().horizontalAdvance(m_bookmark->title());
 
         if (menu()) {
             width += PADDING + 8;
@@ -140,7 +141,8 @@ void BookmarksToolbarButton::menuAboutToShow()
     Q_ASSERT(qobject_cast<Menu*>(sender()));
     Menu *menu = static_cast<Menu*>(sender());
 
-    foreach (QAction *action, menu->actions()) {
+    const auto menuActions = menu->actions();
+    for (QAction *action : menuActions) {
         BookmarkItem *item = static_cast<BookmarkItem*>(action->data().value<void*>());
         if (item && item->type() == BookmarkItem::Url && action->icon().isNull()) {
             action->setIcon(item->icon());
@@ -157,7 +159,7 @@ void BookmarksToolbarButton::menuMiddleClicked(Menu* menu)
 
 void BookmarksToolbarButton::bookmarkActivated(BookmarkItem* item)
 {
-    if (QAction* action = qobject_cast<QAction*>(sender())) {
+    if (auto* action = qobject_cast<QAction*>(sender())) {
         item = static_cast<BookmarkItem*>(action->data().value<void*>());
     }
 
@@ -167,7 +169,7 @@ void BookmarksToolbarButton::bookmarkActivated(BookmarkItem* item)
 
 void BookmarksToolbarButton::bookmarkCtrlActivated(BookmarkItem* item)
 {
-    if (QAction* action = qobject_cast<QAction*>(sender())) {
+    if (auto* action = qobject_cast<QAction*>(sender())) {
         item = static_cast<BookmarkItem*>(action->data().value<void*>());
     }
 
@@ -177,7 +179,7 @@ void BookmarksToolbarButton::bookmarkCtrlActivated(BookmarkItem* item)
 
 void BookmarksToolbarButton::bookmarkShiftActivated(BookmarkItem* item)
 {
-    if (QAction* action = qobject_cast<QAction*>(sender())) {
+    if (auto* action = qobject_cast<QAction*>(sender())) {
         item = static_cast<BookmarkItem*>(action->data().value<void*>());
     }
 
@@ -316,8 +318,8 @@ void BookmarksToolbarButton::mouseMoveEvent(QMouseEvent *event)
 
     setDown(false);
 
-    QDrag *drag = new QDrag(this);
-    BookmarksButtonMimeData* mime = new BookmarksButtonMimeData;
+    auto *drag = new QDrag(this);
+    auto* mime = new BookmarksButtonMimeData;
     mime->setBookmarkItem(m_bookmark);
     drag->setMimeData(mime);
     drag->setPixmap(grab());
@@ -424,7 +426,7 @@ void BookmarksToolbarButton::dropEvent(QDropEvent *event)
     BookmarkItem* bookmark = nullptr;
 
     if (mime->hasFormat(BookmarksButtonMimeData::mimeType())) {
-        const BookmarksButtonMimeData* bookmarkMime = static_cast<const BookmarksButtonMimeData*>(mime);
+        const auto* bookmarkMime = static_cast<const BookmarksButtonMimeData*>(mime);
         bookmark = bookmarkMime->item();
     } else {
         const QUrl url = mime->urls().at(0);
