@@ -35,8 +35,8 @@ class FALKON_EXPORT BrowsingLibrary : public QWidget
     Q_OBJECT
 
 public:
-    explicit BrowsingLibrary(BrowserWindow* window, QWidget* parent = 0);
-    ~BrowsingLibrary();
+    explicit BrowsingLibrary(BrowserWindow* window, QWidget* parent = nullptr);
+    ~BrowsingLibrary() override;
 
     void showHistory(BrowserWindow* window);
     void showBookmarks(BrowserWindow* window);
