@@ -25,7 +25,6 @@
 #include <QDir>
 #include <QCryptographicHash>
 #include <QFileDialog>
-#include <QWebEnginePage>
 #include <QImage>
 #include <QJsonDocument>
 
@@ -40,8 +39,8 @@ SpeedDial::SpeedDial(QObject* parent)
     , m_regenerateScript(true)
 {
     m_autoSaver = new AutoSaver(this);
-    connect(m_autoSaver, SIGNAL(save()), this, SLOT(saveSettings()));
-    connect(this, SIGNAL(pagesChanged()), m_autoSaver, SLOT(changeOccurred()));
+    connect(m_autoSaver, &AutoSaver::save, this, &SpeedDial::saveSettings);
+    connect(this, &SpeedDial::pagesChanged, m_autoSaver, &AutoSaver::changeOccurred);
 }
 
 SpeedDial::~SpeedDial()
@@ -96,13 +95,13 @@ SpeedDial::Page SpeedDial::pageForUrl(const QUrl &url)
     if (urlString.endsWith(QL1C('/')))
         urlString = urlString.left(urlString.size() - 1);
 
-    foreach (const Page &page, m_pages) {
+    for (const Page &page : qAsConst(m_pages)) {
         if (page.url == urlString) {
             return page;
         }
     }
 
-    return Page();
+    return {};
 }
 
 QUrl SpeedDial::urlForShortcut(int key)
@@ -110,7 +109,7 @@ QUrl SpeedDial::urlForShortcut(int key)
     ENSURE_LOADED;
 
     if (key < 0 || m_pages.count() <= key) {
-        return QUrl();
+        return {};
     }
 
     return QUrl::fromEncoded(m_pages.at(key).url.toUtf8());
@@ -131,7 +130,7 @@ void SpeedDial::addPage(const QUrl &url, const QString &title)
     m_pages.append(page);
     m_regenerateScript = true;
 
-    emit pagesChanged();
+    Q_EMIT pagesChanged();
 }
 
 void SpeedDial::removePage(const Page &page)
@@ -146,7 +145,7 @@ void SpeedDial::removePage(const Page &page)
     m_pages.removeAll(page);
     m_regenerateScript = true;
 
-    emit pagesChanged();
+    Q_EMIT pagesChanged();
 }
 
 int SpeedDial::pagesInRow()
@@ -202,7 +201,7 @@ QString SpeedDial::initialScript()
 
     QVariantList pages;
 
-    foreach (const Page &page, m_pages) {
+    for (const Page &page : qAsConst(m_pages)) {
         QString imgSource = m_thumbnailsDir + QCryptographicHash::hash(page.url.toUtf8(), QCryptographicHash::Md4).toHex() + ".png";
 
         if (!QFile(imgSource).exists()) {
@@ -229,15 +228,15 @@ QString SpeedDial::initialScript()
 
 void SpeedDial::changed(const QString &allPages)
 {
-    const QStringList entries = allPages.split(QLatin1String("\";"), QString::SkipEmptyParts);
+    const QStringList entries = allPages.split(QLatin1String("\";"), Qt::SkipEmptyParts);
     m_pages.clear();
 
-    foreach (const QString &entry, entries) {
+    for (const QString &entry : entries) {
         if (entry.isEmpty()) {
             continue;
         }
 
-        const QStringList tmp = entry.split(QLatin1String("\"|"), QString::SkipEmptyParts);
+        const QStringList tmp = entry.split(QLatin1String("\"|"), Qt::SkipEmptyParts);
         if (tmp.count() != 2) {
             continue;
         }
@@ -253,15 +252,15 @@ void SpeedDial::changed(const QString &allPages)
     }
 
     m_regenerateScript = true;
-    emit pagesChanged();
+    Q_EMIT pagesChanged();
 }
 
 void SpeedDial::loadThumbnail(const QString &url, bool loadTitle)
 {
-    PageThumbnailer* thumbnailer = new PageThumbnailer(this);
+    auto* thumbnailer = new PageThumbnailer(this);
     thumbnailer->setUrl(QUrl::fromEncoded(url.toUtf8()));
     thumbnailer->setLoadTitle(loadTitle);
-    connect(thumbnailer, SIGNAL(thumbnailCreated(QPixmap)), this, SLOT(thumbnailCreated(QPixmap)));
+    connect(thumbnailer, &PageThumbnailer::thumbnailCreated, this, &SpeedDial::thumbnailCreated);
 
     thumbnailer->start();
 }
@@ -281,7 +280,7 @@ QStringList SpeedDial::getOpenFileName()
     const QString image = QzTools::getOpenFileName("SpeedDial-GetOpenFileName", 0, tr("Click to select image..."), QDir::homePath(), fileTypes);
 
     if (image.isEmpty())
-        return QStringList();
+        return {};
 
     return {QzTools::pixmapToDataUrl(QPixmap(image)).toString(), QUrl::fromLocalFile(image).toEncoded()};
 }
@@ -321,7 +320,7 @@ void SpeedDial::setSdCentered(bool centered)
 
 void SpeedDial::thumbnailCreated(const QPixmap &pixmap)
 {
-    PageThumbnailer* thumbnailer = qobject_cast<PageThumbnailer*>(sender());
+    auto* thumbnailer = qobject_cast<PageThumbnailer*>(sender());
     if (!thumbnailer) {
         return;
     }
@@ -346,9 +345,9 @@ void SpeedDial::thumbnailCreated(const QPixmap &pixmap)
     thumbnailer->deleteLater();
 
     if (loadTitle)
-        emit pageTitleLoaded(url, title);
+        Q_EMIT pageTitleLoaded(url, title);
 
-    emit thumbnailLoaded(url, QzTools::pixmapToDataUrl(QPixmap(fileName)).toString());
+    Q_EMIT thumbnailLoaded(url, QzTools::pixmapToDataUrl(QPixmap(fileName)).toString());
 }
 
 QString SpeedDial::escapeTitle(QString title) const
@@ -369,10 +368,17 @@ QString SpeedDial::generateAllPages()
 {
     QString allPages;
 
-    foreach (const Page &page, m_pages) {
-        const QString string = QString("url:\"%1\"|title:\"%2\";").arg(page.url, page.title);
+    for (const Page &page : qAsConst(m_pages)) {
+        const QString string = QString(R"(url:"%1"|title:"%2";)").arg(page.url, page.title);
         allPages.append(string);
     }
 
     return allPages;
 }
+
+QList<SpeedDial::Page> SpeedDial::pages()
+{
+    ENSURE_LOADED;
+
+    return m_pages;
+}
