@@ -69,14 +69,14 @@ static QString createLanguageItem(const QString &lang)
         return lang;
     }
 
-    QString country = QLocale::countryToString(locale.country());
-    QString language = QLocale::languageToString(locale.language());
+    const QString country = QLocale::countryToString(locale.country());
+    const QString language = QLocale::languageToString(locale.language());
 
     if (lang == QLatin1String("es_ES")) {
         return QString::fromUtf8("Castellano");
     }
     if (lang == QLatin1String("nqo")) {
-        return QString("N'ko (nqo)");
+        return {"N'ko (nqo)"};
     }
     if (lang == QLatin1String("sr")) {
         return QString::fromUtf8("српски екавски");
@@ -90,7 +90,7 @@ static QString createLanguageItem(const QString &lang)
     if (lang == QLatin1String("sr@ijekavianlatin")) {
         return QString::fromUtf8("srpski ijekavski");
     }
-    return QString("%1, %2 (%3)").arg(language, country, lang);
+    return QStringLiteral("%1, %2 (%3)").arg(language, country, lang);
 }
 
 Preferences::Preferences(BrowserWindow* window)
@@ -112,32 +112,24 @@ Preferences::Preferences(BrowserWindow* window)
     ui->checkUpdates->setVisible(false);
 #endif
 
-#if QTWEBENGINEWIDGETS_VERSION < QT_VERSION_CHECK(5, 11, 0)
-    ui->disableVideoAutoPlay->setVisible(false);
-    ui->webRTCPublicIpOnly->setVisible(false);
-#endif
-
-#if QTWEBENGINEWIDGETS_VERSION < QT_VERSION_CHECK(5, 12, 0)
-    ui->dnsPrefetch->setVisible(false);
-#endif
 
     auto setCategoryIcon = [this](int index, const QIcon &icon) {
         ui->listWidget->item(index)->setIcon(QIcon(icon.pixmap(32)));
     };
 
-    setCategoryIcon(0, QIcon(":/icons/preferences/general.svg"));
-    setCategoryIcon(1, QIcon(":/icons/preferences/appearance.svg"));
-    setCategoryIcon(2, QIcon(":/icons/preferences/tabs.svg"));
-    setCategoryIcon(3, QIcon(":/icons/preferences/browsing.svg"));
-    setCategoryIcon(4, QIcon(":/icons/preferences/fonts.svg"));
-    setCategoryIcon(5, QIcon(":/icons/preferences/shortcuts.svg"));
-    setCategoryIcon(6, QIcon(":/icons/preferences/downloads.svg"));
-    setCategoryIcon(7, QIcon(":/icons/preferences/passwords.svg"));
-    setCategoryIcon(8, QIcon(":/icons/preferences/privacy.svg"));
-    setCategoryIcon(9, QIcon(":/icons/preferences/notifications.svg"));
-    setCategoryIcon(10, QIcon(":/icons/preferences/extensions.svg"));
-    setCategoryIcon(11, QIcon(":/icons/preferences/spellcheck.svg"));
-    setCategoryIcon(12, QIcon(":/icons/preferences/other.svg"));
+    setCategoryIcon(0, QIcon(QStringLiteral(":/icons/preferences/general.svg")));
+    setCategoryIcon(1, QIcon(QStringLiteral(":/icons/preferences/appearance.svg")));
+    setCategoryIcon(2, QIcon(QStringLiteral(":/icons/preferences/tabs.svg")));
+    setCategoryIcon(3, QIcon(QStringLiteral(":/icons/preferences/browsing.svg")));
+    setCategoryIcon(4, QIcon(QStringLiteral(":/icons/preferences/fonts.svg")));
+    setCategoryIcon(5, QIcon(QStringLiteral(":/icons/preferences/shortcuts.svg")));
+    setCategoryIcon(6, QIcon(QStringLiteral(":/icons/preferences/downloads.svg")));
+    setCategoryIcon(7, QIcon(QStringLiteral(":/icons/preferences/passwords.svg")));
+    setCategoryIcon(8, QIcon(QStringLiteral(":/icons/preferences/privacy.svg")));
+    setCategoryIcon(9, QIcon(QStringLiteral(":/icons/preferences/notifications.svg")));
+    setCategoryIcon(10, QIcon(QStringLiteral(":/icons/preferences/extensions.svg")));
+    setCategoryIcon(11, QIcon(QStringLiteral(":/icons/preferences/spellcheck.svg")));
+    setCategoryIcon(12, QIcon(QStringLiteral(":/icons/preferences/other.svg")));
 
     Settings settings;
     //GENERAL URLs
@@ -206,10 +198,11 @@ Preferences::Preferences(BrowserWindow* window)
 
     // PROFILES
     QString startingProfile = ProfileManager::startingProfile();
-    ui->activeProfile->setText("<b>" + ProfileManager::currentProfile() + "</b>");
+    ui->activeProfile->setText(QStringLiteral("<b>") + ProfileManager::currentProfile() + QStringLiteral("</b>"));
     ui->startProfile->addItem(startingProfile);
 
-    foreach (const QString &name, ProfileManager::availableProfiles()) {
+    const auto names = ProfileManager::availableProfiles();
+    for (const QString &name : names) {
         if (startingProfile != name) {
             ui->startProfile->addItem(name);
         }
@@ -283,6 +276,7 @@ Preferences::Preferences(BrowserWindow* window)
     // BROWSING
     settings.beginGroup("Web-Browser-Settings");
     ui->allowPlugins->setChecked(settings.value("allowPlugins", true).toBool());
+    connect(ui->allowPlugins, &QAbstractButton::toggled, this, &Preferences::allowPluginsToggled);
     ui->allowJavaScript->setChecked(settings.value("allowJavaScript", true).toBool());
     ui->linksInFocusChain->setChecked(settings.value("IncludeLinkInFocusChain", false).toBool());
     ui->spatialNavigation->setChecked(settings.value("SpatialNavigation", false).toBool());
@@ -294,8 +288,12 @@ Preferences::Preferences(BrowserWindow* window)
     ui->disableVideoAutoPlay->setChecked(settings.value("DisableVideoAutoPlay", false).toBool());
     ui->webRTCPublicIpOnly->setChecked(settings.value("WebRTCPublicIpOnly", true).toBool());
     ui->dnsPrefetch->setChecked(settings.value("DNSPrefetch", true).toBool());
+    ui->intPDFViewer->setChecked(settings.value("intPDFViewer", false).toBool());
+    ui->intPDFViewer->setEnabled(ui->allowPlugins->isChecked());
+    ui->screenCaptureEnabled->setChecked(settings.value("screenCaptureEnabled", false).toBool());
 
-    foreach (int level, WebView::zoomLevels()) {
+    const auto levels = WebView::zoomLevels();
+    for (int level : levels) {
         ui->defaultZoomLevel->addItem(QString("%1%").arg(level));
     }
     ui->defaultZoomLevel->setCurrentIndex(settings.value("DefaultZoomLevel", WebView::zoomLevels().indexOf(100)).toInt());
@@ -453,7 +451,7 @@ Preferences::Preferences(BrowserWindow* window)
             if (!ui->spellcheckLanguages->findItems(langName, Qt::MatchExactly).isEmpty()) {
                 continue;
             }
-            QListWidgetItem *item = new QListWidgetItem;
+            auto *item = new QListWidgetItem;
             item->setText(langName);
             item->setData(Qt::UserRole, lang);
             item->setFlags(item->flags() & ~Qt::ItemIsSelectable);
@@ -516,7 +514,7 @@ Preferences::Preferences(BrowserWindow* window)
     connect(ui->protocolHandlers, &QAbstractButton::clicked, this, &Preferences::openProtocolHandlersManager);
 
     connect(ui->listWidget, &QListWidget::currentItemChanged, this, &Preferences::showStackedPage);
-    ui->listWidget->setItemSelected(ui->listWidget->itemAt(5, 5), true);
+    ui->listWidget->itemAt(5, 5)->setSelected(true);
 
     ui->listWidget->setCurrentRow(currentSettingsPage);
 
@@ -537,6 +535,11 @@ Preferences::Preferences(BrowserWindow* window)
     QzTools::setWmClass("Preferences", this);
 }
 
+void Preferences::allowPluginsToggled(bool checked)
+{
+    ui->intPDFViewer->setEnabled(checked);
+}
+
 void Preferences::chooseExternalDownloadManager()
 {
     QString path = QzTools::getOpenFileName("Preferences-ExternalDownloadManager", this, tr("Choose executable location..."), QDir::homePath());
@@ -663,7 +666,7 @@ void Preferences::deleteHtml5storage()
 
 void Preferences::openUserAgentManager()
 {
-    UserAgentDialog* dialog = new UserAgentDialog(this);
+    auto* dialog = new UserAgentDialog(this);
     dialog->open();
 }
 
@@ -700,19 +703,19 @@ void Preferences::allowHtml5storageChanged(bool stat)
 
 void Preferences::showCookieManager()
 {
-    CookieManager* dialog = new CookieManager(this);
+    auto* dialog = new CookieManager(this);
     dialog->show();
 }
 
 void Preferences::showHtml5Permissions()
 {
-    HTML5PermissionsDialog* dialog = new HTML5PermissionsDialog(this);
+    auto* dialog = new HTML5PermissionsDialog(this);
     dialog->open();
 }
 
 void Preferences::openJsOptions()
 {
-    JsOptions* dialog = new JsOptions(this);
+    auto* dialog = new JsOptions(this);
     dialog->open();
 }
 
@@ -725,19 +728,19 @@ void Preferences::useExternalDownManagerChanged(bool state)
 
 void Preferences::openSearchEnginesManager()
 {
-    SearchEnginesDialog* dialog = new SearchEnginesDialog(this);
+    auto* dialog = new SearchEnginesDialog(this);
     dialog->open();
 }
 
 void Preferences::openProtocolHandlersManager()
 {
-    ProtocolHandlerDialog *dialog = new ProtocolHandlerDialog(this);
+    auto *dialog = new ProtocolHandlerDialog(this);
     dialog->open();
 }
 
 void Preferences::showAcceptLanguage()
 {
-    AcceptLanguage* dialog = new AcceptLanguage(this);
+    auto* dialog = new AcceptLanguage(this);
     dialog->open();
 }
 
@@ -957,6 +960,8 @@ void Preferences::saveSettings()
     settings.setValue("DisableVideoAutoPlay", ui->disableVideoAutoPlay->isChecked());
     settings.setValue("WebRTCPublicIpOnly", ui->webRTCPublicIpOnly->isChecked());
     settings.setValue("DNSPrefetch", ui->dnsPrefetch->isChecked());
+    settings.setValue("intPDFViewer", ui->intPDFViewer->isChecked());
+    settings.setValue("screenCaptureEnabled", ui->screenCaptureEnabled->isChecked());
 
 #ifdef Q_OS_WIN
     settings.setValue("CheckDefaultBrowser", ui->checkDefaultBrowser->isChecked());
